@@ -19,7 +19,7 @@
 #' @references \url{http://www.naturalearthdata.com/downloads/10m-cultural-vectors/}
 #' @seealso SimpleCountries
 #' @seealso getSpatialData
-getCountry <- function(lon, lat, dataset='SimpleCountries', countryCodes=NULL, allData=FALSE, useBuffering=FALSE) {
+getCountry <- function(lon, lat, dataset='SimpleCountriesEEZ', countryCodes=NULL, allData=FALSE, useBuffering=FALSE) {
   
   # Sanity check
   if (!exists(dataset)) {
@@ -48,7 +48,6 @@ getCountry <- function(lon, lat, dataset='SimpleCountries', countryCodes=NULL, a
     
     countryName <- locationsDF$countryName
     
-    
     return(countryName)
     
   }
