@@ -6,7 +6,7 @@
 #' @param dataset name of spatial dataset to use
 #' @param countryCodes vector of countryCodes
 #' @param allData logical specifying whether a full dataframe should be returned
-#' @param useBuffering logical flag specyfing the use of location buffering to find the nearest polygon if not target polygon is found
+#' @param useBuffering logical flag specifying the use of location buffering to find the nearest polygon if no target polygon is found
 #' @description Uses spatial comparison to determine which country polygons the 
 #'     locations fall into and returns the country code strings for those polygons.
 #'     
@@ -19,7 +19,7 @@
 #' @references \url{http://www.naturalearthdata.com/downloads/10m-cultural-vectors/}
 #' @seealso SimpleCountries
 #' @seealso getSpatialData
-getCountryCode <- function(lon, lat, dataset='SimpleCountries', countryCodes=NULL, allData=FALSE, useBuffering=FALSE) {
+getCountryCode <- function(lon, lat, dataset='SimpleCountriesEEZ', countryCodes=NULL, allData=FALSE, useBuffering=FALSE) {
   
   # Sanity check
   if (!exists(dataset)) {
@@ -48,12 +48,9 @@ getCountryCode <- function(lon, lat, dataset='SimpleCountries', countryCodes=NUL
     
     countryCode <- locationsDF$countryCode
     
-
-    
     return(countryCode)
     
   }
   
-  
 }
 
